#
# spec file for package python-statsmodels
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-statsmodels%{psuffix}
Version:        0.14.3
Release:        1.1
Summary:        A Python module that allows users to explore data
License:        BSD-3-Clause
URL:            https://github.com/statsmodels/statsmodels
Source:         https://files.pythonhosted.org/packages/source/s/statsmodels/statsmodels-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 3.0.10 with %python-Cython < 4}
BuildRequires:  %{python_module devel >= 3.9}
BuildRequires:  %{python_module numpy-devel >= 1.22.3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scipy >= 1.8}
BuildRequires:  %{python_module setuptools >= 0.69.0.2}
BuildRequires:  %{python_module setuptools_scm >= 8}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.22.3
Requires:       python-packaging >= 21.3
Requires:       python-pandas >= 1.4
Requires:       python-patsy >= 0.5.6
Requires:       python-scipy >= 1.8
Recommends:     python-matplotlib >= 3
%if %{with test}
# SECTION mandatory
BuildRequires:  %{python_module statsmodels = %{version}}
# /SECTION
# SECTION optional
BuildRequires:  %{python_module matplotlib >= 3}
# /SECTION
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module pytest >= 7.0.1}
BuildRequires:  %{python_module pytest-xdist}
# /SECTION
%endif
%python_subpackages

%description
Statsmodels is a Python module that allows users to explore data,
estimate statistical models, and perform statistical tests.
An extensive list of descriptive statistics, statistical tests,
plotting functions, and result statistics are available for different
types of data and each estimator. Researchers across fields may find
that statsmodels fully meets their needs for statistical computing
and data analysis in Python.

%prep
%autosetup -p1 -n statsmodels-%{version}

rm -rf statsmodels/.pytest_cache
find . -type f -name "*.py" -exec sed -i -e '1{/env python/ d}' -e 's/\r$//' {} \;
find . -type f -exec chmod a-x {} \;
find . -type f -name "*.ipynb" -exec sed -i 's/\r$//' {} \;
find . -type f -name "*.csv" -exec sed -i 's/\r$//' {} \;
sed -i 's/\r$//' COPYRIGHTS.txt
sed -i 's/\r$//' LICENSE.txt
sed -i 's/\r$//' README.rst
sed -i 's/\r$//' README_l1.txt

%build
%if !%{with test}
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%check
%if %{with test}
# The tests expect an in-place built source tree. Work around conftest import conflicts
# by directly discovering tests in installed sitearch.
testdir=/tmp/%{name}-testdir
rm -rf $testdir
mkdir $testdir
cp setup.cfg $testdir
pushd $testdir
# test results not packaged: https://github.com/statsmodels/statsmodels/issues/8928, test_stl see below
donttest="test_mstl"
%ifarch %{ix86} %{arm32}
# Note: there is no upstream 32-bit support for testing
# gh#statsmodels/statsmodels#7463
donttest="$donttest or test_seasonal_order"
donttest="$donttest or (test_holtwinters and test_forecast_index)"
donttest="$donttest or (test_discrete and test_basic)"
donttest="$donttest or test_fit_regularized"
%endif
# not slow: some tests in tsa and discrete take AGES to run in OBS, like 2h per the folder
%pytest_arch -n auto -p no:cacheprovider -m "not slow" -k "not (${donttest})" %{$python_sitearch}/statsmodels --ignore %{$python_sitearch}/statsmodels/tsa/stl/tests/test_stl.py
popd
rm -r $testdir
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst README_l1.txt
%doc examples/
%license COPYRIGHTS.txt LICENSE.txt
%{python_sitearch}/statsmodels/
%{python_sitearch}/statsmodels-%{version}.dist-info
%endif

%changelog
* Thu Sep 26 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.14.3
  * Improves compatibility with recent pandas releases
* Mon Apr 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.14.2
  * Full compatibility with NumPy 2
  * Improved future proofing against pandas 3 changes
- Drop statsmodels-pr9106-numpy2.patch
* Thu Mar 21 2024 Ben Greiner <code@bnavigator.de>
- Add statsmodels-pr9106-numpy2.patch for deprecation warnings with
  numpy and pandas -- gh#statsmodels/statsmodels#9106
- Update BuildRequirements: Cython 3 is okay
* Fri Feb  9 2024 Christian Keil <keil@dfn-cert.de>
- Switch to Python 3.11 build.
* Fri Jan 12 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  * This is a bug fix and future-proofing release that contains
    all bug fixes that have been applied since 0.14.0 was
    released.
* Fri Jun 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14.0
  * Treatment effect estimation and inference
  * Hurdle and Truncated Count Regression
  * Archimedean copulas have been extended to more than
    2-dimensions.
  * Multiseason STL decomposition (MSTL)
  * Improved compatibility with current and future NumPy, SciPy,
    and pandas.
- Drop use_old_setuptools_scm.patch
* Thu Jan 12 2023 Ben Greiner <code@bnavigator.de>
- Don't remove the tests after install, we need them in the check
  section.
* Thu Nov 24 2022 Matej Cepl <mcepl@suse.com>
- Add use_old_setuptools_scm.patch allowing use older version
  setuptools_scm.
* Wed Nov  9 2022 Ben Greiner <code@bnavigator.de>
- Fix build requirements
- Clean specfile
- Skip more 32-bit tests, unsupported upstream
* Tue Nov  8 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.13.5:
  * Python 3.11 compatibility
  * resolves an issue with PyPI that affects 0.13.4
  * packaging fixes
- Add python module Jinja2, needed for tests in %%check
* Sun Mar 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.13.2
  * Autoregressive Distributed Lag models
  * Copulas
  * Ordered Models (Ordinal Regression)
  * Beta Regression
  * Improvements to ARIMA estimation options
  * Python 3.10 support
  * Protection against changes in recent versions of upstream
    packages
- Drop patches merged upstream
  * statsmodels-pr7373-future-sp-pd-mpl.patch
  * statsmodels-pr7737-32bit-iloc-dtype.patch
* Tue Sep 21 2021 Ben Greiner <code@bnavigator.de>
- Fix 32-bit test failures
  * Add statsmodels-pr7737-32bit-iloc-dtype.patch
  * gh#statsmodels/statsmodels#7736
* Mon Sep 20 2021 Ben Greiner <code@bnavigator.de>
- Fix rpmlint: executable bits and script interpreter lines
- Add statsmodels-pr7373-future-sp-pd-mpl.patch for test errors due
  to updated dependencies.
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.12.2
  * This is a bug-fix release from the 0.12.x branch. Users are
    encouraged to upgrade.
  * Notable changes include fixes for a bug that could lead to
    incorrect results in forecasts with the new ARIMA model
    (when d > 0 and trend='t') and a bug in the LM test for
    autocorrelation.
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python 36 (scipy)
* Sun Jan  3 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 0.12.1
  * Bugfix release
- Changelog for 0.12.0 (huge):
  https://www.statsmodels.org/devel/release/version0.12.html
- fix test suite setup
* Mon Apr  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to not take ages on running tests and
  blocking all depending packages
* Mon Apr  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.11.1:
  * Bugfixes all around
  * upstream declare dropped support for python2
* Sun Nov 24 2019 Arun Persaud <arun@gmx.de>
- update to version 0.10.2:
  * This is a bug release and adds compatibility with Python 3.8.
* Mon Jul 29 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Stop packaging unreproducible .pyc files
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.10.1
  * Bugfix release
- Update to 0.10.0
  Highlights:
  * Generalized Additive Models
  * Conditional Models
  * Dimension Reduction Methods
  * Regression using Quadratic Inference Functions (QIF)
  * Gaussian Process Regression
  * Burg's Method
  * Time series Tools
  * Knockoff effect estimation has been added for a many models
  * Influence functions are available for GLM and generic MLE models:
- Remove upstream-included pandas_to_datetime.patch
* Tue Aug 14 2018 toddrme2178@gmail.com
- Update to 0.9.0
  Highlights:
  * statespace refactoring, Markov Switching Kim smoother
  * Bayesian mixed GLM
  * Gaussian Imputation
  * new multivariate methods: factor analysis, MANOVA, repeated measures within ANOVA
  * GLM var_weights in addition to freq_weights
  * Holt-Winters and Exponential Smoothing
- Add pandas_to_datetime.patch
  to_datetime has been moved in pandas.
  Should be in next release
  From: https://github.com/statsmodels/statsmodels/pull/4640
* Thu May  4 2017 toddrme2178@gmail.com
- Update to 0.8.0 final
  * The main features of this release are several new time series models based
    on the statespace framework, multiple imputation using MICE as well as many
    other enhancements. The codebase also has been updated to be compatible with
    recent numpy and pandas releases.
  * For a full ist see: http://www.statsmodels.org/stable/release/version0.8.html
- Implement single-spec version
* Fri Oct 28 2016 toddrme2178@gmail.com
- Fix download URL.
* Fri Oct 28 2016 toddrme2178@gmail.com
- Update to Release 0.8.0rc1
  + Release summary
    The main features of this release are several new time series models based
    on the statespace framework, multiple imputation using MICE as well as many
    other enhancements. The codebase also has been updated to be compatible with
    recent numpy and pandas releases.
  + Statespace Models
  * Building on the statespace framework and models added in 0.7, this release
    includes additional models that build on it.
  + Kalman Smoother
  * The Kalman smoother (introduced in #2434) allows making inference on the
    unobserved state vector at each point in time using data from the entire
    sample. In addition to this improved inference, the Kalman smoother is required
    for future improvements such as simulation smoothing and the expectation
    maximization (EM) algorithm.
  * As a result of this improvement, all state space models now inherit a `smooth`
    method for producing results with smoothed state estimates. In addition, the
    `fit` method will return results with smoothed estimates at the maximum
    likelihood estimates.
  + Postestimation
  * Improved post-estimation output is now available to all state space models
    (introduced in #2566). This includes the new methods `get_prediction` and
    `get_forecast`, providing standard errors and confidence intervals as well
    as point estimates, `simulate`, providing simulation of time series following
    the given state space process, and `impulse_responses`, allowing computation
    of impulse responses due to innovations to the state vector.
  + Diagnostics
  * `test_normality` implements the Jarque-Bera test for normality of residuals
  * `test_heteroskedasticity` implements a test for homoskedasticity of
    residuals similar to the Goldfeld-Quandt test
  * `test_serial_correlation` implements the Ljung-Box (or Box-Pierce) test for
    serial correlation of residuals
  + Unobserved Components
  * The class of univariate Unobserved Components models (also known as structural
    time series models) are now available (introduced in #2432). This includes as
    special cases the local level model and local linear trend model. Generically
    it allows decomposing a time series into trend, cycle, seasonal, and
    irregular components, optionally with exogenous regressors and / or
    autoregressive errors.
  + Multivariate Models
  * Two standard multivariate econometric models - vector autoregressive
    moving-average model with exogenous regressors (VARMAX) and Dynamic Factors
    models - are now available (introduced in #2563). The first is a popular
    reduced form method of exploring the covariance in several time series, and the
    second is a popular reduced form method of extracting a small number of common
    factors from a large dataset of observed series.
  + Recursive least squares
  * A model for recursive least squares, also known as expanding-window OLS, is
    now available in `statsmodels.regression` (introduced in #2830).
  + Other improvements to the state space framework include:
  * Improved missing data handling #2770, #2809
  * Ongoing refactoring and bug fixes in fringes and corner cases
  + New functionality in statistics
  * Contingency Tables #2418 (Kerby Shedden)
  * Local FDR, multiple testing #2297 (Kerby Shedden)
  * Mediation Analysis #2352 (Kerby Shedden)
  * weighted quantiles in DescrStatsW #2707 (Kerby Shedden)
  + Duration
  * Kaplan Meier Survival Function #2614 (Kerby Shedden)
  * Cumulative incidence rate function #3016 (Kerby Shedden)
  * frequency weights in Kaplan-Meier #2992 (Kerby Shedden)
  + Imputation
  * new subpackage in `statsmodels.imputation`
  * MICE #2076  (Frank Cheng GSOC 2014 and Kerby Shedden)
  * Imputation by regression on Order Statistic  #3019 (Paul Hobson)
  + Time Series Analysis
  * Markov Switching Models
    Markov switching dynamic regression and autoregression models are now
    available (introduced in #2980 by Chad Fulton). These models allow regression
    effects and / or autoregressive dynamics to differ depending on an unobserved
    "regime"; in Markov switching models, the regimes are assumed to transition
    according to a Markov process.
  + Statistics
  * KPSS stationarity, unit root test #2775 (N-Wouda)
  * The Brock Dechert Scheinkman (BDS) test for nonlinear dependence is now
    available (introduced in #934 by Chad Fulton)
  + Penalized Estimation
  * Elastic net: fit_regularized with L1/L2 penalization has been added to
    OLS, GLM and PHReg (Kerby Shedden)
  + GLM
  * Tweedie is now available as new family #2872 (Peter Quackenbush, Josef Perktold)
  * frequency weights for GLM (currently without full support) #
  * more flexible convergence options #2803 (Peter Quackenbush)
  + Multivariate
  * new subpackage that currently contains PCA
  * PCA was added in 0.7 to statsmodels.tools and is now in statsmodels.multivariate
  + Documentation
  * New doc build with latest jupyter and Python 3 compatibility (Tom Augspurger)
  + several existing functions have received improvements
  * seasonal_decompose: improved periodicity handling #2987 (ssktotoro ?)
  * tools add_constant, add_trend: refactoring and pandas compatibility #2240 (Kevin Sheppard)
  * acf, pacf, acovf: option for missing handling #3020 (joesnacks ?)
  * acf, pacf plots: allow array of lags #2989 (Kevin Sheppard)
  * io SimpleTable (summary): allow names with special characters #3015 (tvanessa ?)
  * tsa tools lagmat, lagmat2ds: pandas support #2310 #3042 (Kevin Sheppard)
  * CompareMeans: from_data, summary methods #2754 (Valery Tyumen)
  + Major Bugs fixed
  * see github issues
  + Backwards incompatible changes and deprecations
  * predict now returns a pandas Series if the exog argument is a DataFrame
  * PCA moved to multivariate compared to 0.7
- Update to Release 0.7.0 (never officially released)
  + Principal Component Analysis
  * Options to control the standardization (demeaning/studentizing)
  * Scree plotting
  * Information criteria for selecting the number of factors
  * R-squared plots to assess component fit
  * NIPALS implementation when only a small number of components are required
    and the dataset is large
  * Missing-value filling using the EM algorithm
  + Regression graphics for GLM/GEE
  * Added variable plots, partial residual plots, and CERES residual plots
    are available for GLM and GEE models by calling the methods
    `plot_added_variable`, `plot_partial_residuals`, and
    `plot_ceres_residuals` that are attached to the results classes.
  + State Space Models
  * State space methods provide a flexible structure for the estimation and
    analysis of a wide class of time series models. The Statsmodels implementation
    allows specification of state models, fast Kalman filtering, and built-in
    methods to facilitate maximum likelihood estimation of arbitrary models. One of
    the primary goals of this module is to allow end users to create and estimate
    their own models. Below is a short example demonstrating the ease with which a
    local level model can be specified and estimated:
  + Time Series Models (ARIMA) with Seasonal Effects
  * Additive and multiplicative seasonal effects
  * Flexible trend specications
  * Regression with SARIMA errors
  * Regression with time-varying coefficients
  * Measurement error in the endogenous variables
  + Generalized Estimating Equations GEE
  * EquivalenceClass covariance structure allows covariances to be specified by
    arbitrary collections of equality constraints #2188
  * add weights #2090
  * refactored margins #2158
  + MixedLM
  * added variance components support for MixedLM allowing a wider range of
    random effects structures to be specified
  * performance improvements from use of sparse matrices internally for
    random effects design matrices.
  + Other important new features
  * GLM: add scipy-based gradient optimization to fit #1961 (Kerby Shedden)
  * wald_test_terms: new method of LikelihoodModels to compute wald tests (F or chi-square)
    for terms or sets of coefficients #2132  (Josef Perktold)
  * add cov_type with fixed scale in WLS to allow chi2-fitting #2137 #2143
    (Josef Perktold, Christoph Deil)
  * VAR: allow generalized IRF and FEVD computation #2067 (Josef Perktold)
  * get_prediction new method for full prediction results (new API convention)
  + Major Bugs fixed
  * see github issues for a full list
  * bug in ARMA/ARIMA predict with `exog` #2470
  * bugs in VAR
  * x13: python 3 compatibility
- update to version 0.6.1:
  * PR #2111: Mixed profile
  * PR #2053: Add NominalGEE and OrdinalGEE to api
  * PR #2105: BUG: Avoid returning nans in lowess.
  * PR #2066: fixes #2065 (missing np)
  * PR #2089: BUG: Fix pos. def check in logdet
  * PR #2097: BUG: Make sure RE names are properly handled in MixedLM.
  * PR #2093: Add user control over what happens if a constant is already present.
  * PR #2084: BUG: Correct issue if patsy handles missing. Closes #2083.
  * #2102: MixedLM profile likelihood issue
  * #1798: lowess silently returns nans
  * #2065: In tukey_hsd.plot_simultaneous - “ones” not defined.
  * #2087: slogdet positive-definite check is wrong
  * #2099: Error in accessing mixedlm results with random slopes
  * #2043: ValueError on tsa with constant column
  * #2083: BUG: rlm errors on missing values
* Thu Nov  6 2014 toddrme2178@gmail.com
- Updated to version 0.6.0. Highlights:
  * Generalized Estimating Equation models
  * Linear Mixed Effects Models
  * Wrapper code for using X-12-ARIMA/X13-ARIMA-SEATS
  * Substantial optimization in the ARIMA estimation code
  * Some seasonal time-series features for plotting and decomposition
  * Many other feature enhancments and bug fixes
* Tue Oct 22 2013 toddrme2178@gmail.com
- Update to 0.5.0
  * No changelog available
- Add additional dependencies
* Wed Feb 13 2013 saschpe@suse.de
- Correctly fix non-executable script warnings (bnc#803223)
* Thu Jun 21 2012 scorot@free.fr
- version 0.4.1
  * add lowess and other functions to api and documentation
  * rename lowess module (old import path will be removed at next
  release)
  * new robust sandwich covariance estimators, moved out of sandbox
  * compatibility with pandas 0.8
  * new plots in statsmodels.graphics
  - ABLine plot
  - interaction plot
  * several bug fixes
  - see CHANGES.TXT for details
* Wed Jun 13 2012 scorot@free.fr
- use proper commands instead of deprecated macro
- remove unneeded -01 and --skip-build flags from the install
  command line
- set install prefix with %%%%{_prefix} instead of hard coded path
* Tue Jun 12 2012 scorot@free.fr
- first package
